@@ -39,7 +39,6 @@ if not hasattr(setuptools, "_distribute"):
 
 def setup(*args, **kwargs):
     from setuptools import setup
-    import traceback
     try:
         setup(*args, **kwargs)
     except KeyboardInterrupt:
@@ -85,17 +84,8 @@ class NumpyExtension(Extension):
 
 class PyUblasExtension(NumpyExtension):
     def get_module_include_path(self, name):
-        from imp import find_module
-        file, pathname, descr = find_module(name)
-        from os.path import join, exists
-        installed_path = join(pathname, "..", "include")
-        development_path = join(pathname, "..", "src", "cpp")
-        if exists(installed_path):
-            return installed_path
-        elif exists(development_path):
-            return development_path
-        else:
-            raise RuntimeError("could not find C include path for module '%s'" % name)
+        from pkg_resources import Requirement, resource_filename
+        return resource_filename(Requirement.parse(name), "%s/include" % name)
 
     @property
     def include_dirs(self):
@@ -165,7 +155,7 @@ def get_config(schema=None, warn_about_no_config=True):
 
         count_down_delay(delay=10)
 
-    return schema.read_config()
+    return expand_options(schema.read_config())
 
 
 
@@ -241,15 +231,23 @@ def expand_value(v, options):
     if isinstance(v, str):
         return expand_str(v, options)
     elif isinstance(v, list):
-        return [expand_value(i, options) for i in v]
+        result = []
+        for i in v:
+            try:
+                exp_i = expand_value(i, options)
+            except:
+                pass
+            else:
+                result.append(exp_i)
+
+        return result
     else:
         return v
 
 
 def expand_options(options):
-    for k in options.keys():
-        options[k] = expand_value(options[k], options)
-    return options
+    return dict(
+            (k, expand_value(v, options)) for k, v in options.items())
 
 
 
@@ -280,8 +278,7 @@ class ConfigSchema:
         self.conf_dir = conf_dir
 
     def get_default_config(self):
-        return dict((opt.name, opt.default)
-                for opt in self.options)
+        return dict((opt.name, opt.default) for opt in self.options)
 
     def read_config_from_pyfile(self, filename):
         result = {}
@@ -309,7 +306,8 @@ class ConfigSchema:
         except IOError:
             pass
 
-        del filevars["__builtins__"]
+        if "__builtins__" in filevars:
+            del filevars["__builtins__"]
 
         for key, value in config.items():
             if value is not None:
@@ -379,8 +377,6 @@ class ConfigSchema:
                     raise KeyError("invalid config key in %s: %s" % (
                             cfile, key))
 
-        expand_options(result)
-
         return result
 
     def add_to_configparser(self, parser, def_config=None):
@@ -395,11 +391,9 @@ class ConfigSchema:
         result = {}
         for opt in self.options:
             result[opt.name] = opt.take_from_configparser(options)
-        expand_options(result)
         return result
 
     def write_config(self, config):
-        import os
         outf = open(self.get_conf_file(), "w")
         for opt in self.options:
             value = config[opt.name]
@@ -482,7 +476,7 @@ class StringListOption(Option):
         if default is None:
             return None
 
-        return ",".join([str(el) for el in default])
+        return ",".join([str(el).replace(",", r"\,") for el in default])
 
     def get_help(self, default):
         return Option.get_help(self, default) + " (several ok)"
@@ -493,7 +487,11 @@ class StringListOption(Option):
             return None
         else:
             if opt:
-                return opt.split(",")
+                import re
+                sep = re.compile(r"(?<!\\),")
+                result = sep.split(opt)
+                result = [i.replace(r"\,", ",") for i in result]
+                return result
             else:
                 return []
 
@@ -517,9 +515,16 @@ class Libraries(StringListOption):
                 % (human_name or humanize(lib_name))))
 
 class BoostLibraries(Libraries):
-    def __init__(self, lib_base_name):
+    def __init__(self, lib_base_name, default_lib_name=None):
+        if default_lib_name is None:
+            if lib_base_name == "python":
+                import sys
+                default_lib_name = "boost_python-py%d%d" % sys.version_info[:2]
+            else:
+                default_lib_name = "boost_%s" % lib_base_name
+
         Libraries.__init__(self, "BOOST_%s" % lib_base_name.upper(),
-                ["boost_%s-${BOOST_COMPILER}-mt" % lib_base_name],
+                [default_lib_name],
                 help="Library names for Boost C++ %s library (without lib or .so)"
                     % humanize(lib_base_name))
 
@@ -540,8 +545,7 @@ def set_up_shipped_boost_if_requested(project_name, conf):
             print("------------------------------------------------------------------------")
             print("If you got this package from git, you probably want to do")
             print("")
-            print(" $ git submodule init")
-            print(" $ git submodule update")
+            print(" $ git submodule update --init")
             print("")
             print("to fetch what you are presently missing. If you got this from")
             print("a distributed package on the net, that package is broken and")
@@ -565,12 +569,17 @@ def set_up_shipped_boost_if_requested(project_name, conf):
                 + glob("bpl-subset/bpl_subset/libs/*/*/*.cpp")
                 + glob("bpl-subset/bpl_subset/libs/*/*.cpp"))
 
+        # make sure next line succeeds even on Windows
+        source_files = [f.replace("\\","/") for f in source_files]
+
         source_files = [f for f in source_files
                 if not f.startswith("bpl-subset/bpl_subset/libs/thread/src")]
 
         if sys.platform == "win32":
             source_files += glob(
                     "bpl-subset/bpl_subset/libs/thread/src/win32/*.cpp")
+            source_files += glob(
+                    "bpl-subset/bpl_subset/libs/thread/src/*.cpp")
         else:
             source_files += glob(
                     "bpl-subset/bpl_subset/libs/thread/src/pthread/*.cpp")
@@ -591,7 +600,12 @@ def set_up_shipped_boost_if_requested(project_name, conf):
 
         return (source_files,
                 {
+                    # do not pick up libboost link dependency on windows
+                    "BOOST_ALL_NO_LIB": 1,
+                    "BOOST_THREAD_BUILD_DLL": 1,
+
                     "BOOST_MULTI_INDEX_DISABLE_SERIALIZATION": 1,
+                    "BOOST_THREAD_DONT_USE_CHRONO": 1,
                     "BOOST_PYTHON_SOURCE": 1,
                     "boost": '%sboost' % project_name
                     }
@@ -723,8 +737,8 @@ def check_git_submodules():
         stdout_data, _ = popen.communicate()
         if popen.returncode != 0:
             git_error = "git returned error code %d" % popen.returncode
-    except OSError, e:
-        git_error = e
+    except OSError:
+        git_error = "(os error, likely git not found)"
 
     if git_error is not None:
         print("-------------------------------------------------------------------------")
@@ -734,7 +748,7 @@ def check_git_submodules():
         print("not invoke git to check whether my submodules are up to date.")
         print("")
         print("The error was:")
-        print(e)
+        print(git_error)
         print("Hit Ctrl-C now if you'd like to think about the situation.")
         print("-------------------------------------------------------------------------")
         count_down_delay(delay=5)
@@ -778,8 +792,7 @@ def check_git_submodules():
             print("-------------------------------------------------------------------------")
             print("If this makes no sense, you probably want to say")
             print("")
-            print(" $ git submodule init")
-            print(" $ git submodule update")
+            print(" $ git submodule update --init")
             print("")
             print("to fetch what you are presently missing and move on with your life.")
             print("If you got this from a distributed package on the net, that package is")
@@ -794,7 +807,9 @@ def check_git_submodules():
             print("Hit Ctrl-C now if you'd like to think about the situation.")
             print("-------------------------------------------------------------------------")
 
-            count_down_delay(delay=10)
+            from os.path import exists
+            if not exists(".dirty-git-ok"):
+                count_down_delay(delay=10)
 
 
 
